ANSTO Publications Online: An investigation into transition metal ion binding properties of silk fibers and particles using radioisotopes.

Publications Online

Search APO
Advanced Search
| Home
Browse
| Communities & Collections
| Issue Date
| Author
| Title
| Subject
Sign on to:
| Receive email updates
| My APO authorized users
| Edit Profile
| About DSpace
| ANSTO Publications Online > Journal Publications > Journal Articles >
Please use this identifier to cite or link to this item: `http://apo.ansto.gov.au/dspace/handle/10238/2935`
Title: | An investigation into transition metal ion binding properties of silk fibers and particles using radioisotopes.
Authors: | Rajkhowa, R Naik, R Wang, L Smith, SV Wang, X
Keywords: | Radioisotopes Transition Elements Binding Energy Fibers Absorption Ions
Issue Date: | 15-Mar-2011
Publisher: | Wiley-Blackwell
Citation: | Rajkhowa, R., Naik, R., Wang, L., Smith, S. V., & Wang, X. (2011). An investigation into transition metal ion binding properties of silk fibers and particles using radioisotopes. Journal of Applied Polymer Science, 119(6), 3630-3639.
Abstract: | Silk is a structural protein fiber that is stable over a wide pH range making it attractive for use in medical and environmental applications. Variation in amino acid composition has the potential for selective binding for ions under varying conditions. Here we report on the metal ion separation potential of Mulberry and Eri silk fibers and powders over a range of pH. Highly sensitive radiotracer probes, 64Cu2+, 109Cd2+, and 57Co2+ were used to study the absorption of their respective stable metal ions Cu2+, Cd2+, and Co2+ into and from the silk sorbents. The total amount of each metal ion absorbed and time taken to reach equilibrium occurred in the following order: Cu2+ > Cd2+ > Co2+. In all cases the silk powders absorbed metal ions faster than their respective silk fibers. Intensive degumming of the fibers and powders significantly reduced the time to absorb respective metal ions and the time to reach equilibrium was reduced from hours to 5–15 min at pH 8. Once bound, 45–100% of the metal ions were released from the sorbents after exposure to pH 3 buffer for 30 min. The transition metal ion loading capacity for the silk sorbents was considerably higher than that found for commercial ion exchange resins (AG MP-50 and AG 50W-X2) under similar conditions. Interestingly, total Cu2+ bound was found to be higher than theoretically predicted values based on known specific Cu2+ binding sites (AHGGYSGY), suggesting that additional (new) sites for transition metal ion binding sites are present in silk fibers. © 2011, Wiley-Blackwell. The definitive version is available at www3.interscience.wiley.com
URI: | http://dx.doi.org/10.1002/app.33059 http://apo.ansto.gov.au/dspace/handle/10238/2935
ISSN: | 0021-8995
Appears in Collections: | Journal Articles
Files in This Item: There are no files associated with this item.
Items in APO are protected by copyright, with all rights reserved, unless otherwise indicated.
| DSpace Software Copyright © 2002-2010 Duraspace - Feedback |